@@ -15,7 +15,7 @@ class Middleware:
     def process_request(self, req):
         pass
 
-    def process_request(self, req, res):
+    def process_response(self, req, res):
         pass
 
     def handle_request(self, req):
